/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.openrune;

/**
 * An OpenRune plugin.
 * All plugins must implement this interface in order to
 * provides servers to the OpenRune server.
 * @author ry60003333
 */
public interface Plugin
{
    /**
     * This constant defines an int array that allows
     * a plugin to work with any client version by default.
     */
    public static final int[] ALL_CLIENT_VERSIONS = {};
    
    /**
     * Get the namespace that the plugin resides in.
     * The namespace of the plugin should be in reverse-domain format,
     * much like a Java package.
     * <p>
     * You should use a domain name that you control, 
     * and use of the OpenRune name along with the a name
     * for the plugin is suggested.
     * <p>
     * An example namespace: org.allgofree.openrune.smithing
     * @return The namespace of the plugin.
     */
    public String getNamespace();
    
    /**
     * Get the name of the plugin.
     * The name of the plugin should be a simple, 
     * properly capitalized, human readable name.
     * <p>
     * An example name would be "Smithing" (no quotes).
     * @return The name of the plugin.
     */
    public String getName();

    /**
     * Get the authors of the plugin.
     * An array of String objects should be returned from this method,
     * with each entry in the array containing the name of an author.
     * @return The array containing the authors of the plugin.
     */
    public String[] getAuthor();

    /**
     * Get the build number of the plugin.
     * The build number of the plugin should increase with each release
     * of the plugin. Build numbers will be used in tracking bugs, 
     * so two versions of a plugin should not have the same build number.
     * @return The build number of the plugin.
     */
    public int getBuild();

    /**
     * Get the array of client versions that the plugin can be used with.
     * This method should return an array of ints, with each int
     * specifying a client version. Plugins can also return constants
     * to work by default with any client version. These constants
     * are defined in this interface; the most common being <b>ALL_CLIENT_VERSIONS</b>.
     * @return The versions that the plugin can be used with.
     */
    public int[] getClientVersions();
    
    /**
     * Initialize the plugin.
     * This is where the plugin should register all of it's
     * listeners, loaders, components, and so on. This method
     * may be called more then once if the plugin is unloaded 
     * and then reloaded.
     * @param sandbox The sandbox environment.
     */
    public void init(Sandbox sandbox);
}
