/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package org.openrune.event;

/**
 * An event generated by the game engine.
 * GameEvents can be generated by many different causes, 
 * and EventHandlers will generally down cast this class
 * into a more specific type before handling the GameEvent.
 * @author ry60003333
 */
public interface GameEvent
{
    /**
     * Get the keys that apply to the GameEvent, in order of priority.
     * GameEvents can have multiple <b>keys</b>. Keys are Objects (usually
     * strings) that are put in a HashMap in order to retrieve the associated
     * listeners for that GameEvent.
     * <p>
     * The keys should be returned with the highest priority (most specific) 
     * key at the front of the array. This will allow the more specific
     * EventHandlers to receive the GameEvent first, and possible block
     * the less specific EventHandlers from receiving the GameEvent.
     * @return The array of the keys that apply to the GameEvent.
     */
    public Object[] getKeys();
}
